Learn R Programming

RImpala (version 0.1.6)

rimpala.describe: Function to describe any table present in Hive's metastore

Description

This function runs the describe query of Impala against the table passed as an argument to the function

Usage

rimpala.describe(table)

Arguments

table
The name of the table that needs to be described

Value

Returns an dataframe that contains the details of the table as displayed by the describe command

Examples

Run this code
## Not run: 
# library("RImpala")
# rimpala.init()
# rimpala.connect("127.0.0.1","21050")
# des=rimpala.describe(table="sample_table")
# ## End(Not run)

Run the code above in your browser using DataLab