Learn R Programming

RImpala (version 0.1.6)

rimpala.invalidate: Invalidates the metadata of a one or all tables

Description

This function invalidates metadata of the table passed as an argument to it. Metadata invalidation is required if a table has been changed in Hive.

Usage

rimpala.invalidate(table=" ")

Arguments

table
The name of the table whose metadata needs to be invalidated. Default is NULL

Value

The metadata of the table passed as an argumented is invalidated or marked as stale from the cache. If no argument is passed, all the metadata of all the tables are invalidated.

Examples

Run this code
## Not run: 
# library("RImpala")
# rimpala.init()
# rimpala.connect(IP="127.0.0.1",port="21050")
# rimpala.invalidate(table="sample")
# ## End(Not run)

Run the code above in your browser using DataLab