Learn R Programming

RImpala (version 0.1.6)

rimpala.showtables: Function to display the list of all the tables present

Description

This function retrieves the list of tables present in the current working database

Usage

rimpala.showtables()

Arguments

Value

List of tables present in the current database is returned into a dataframe

Examples

Run this code
## Not run: 
# library("RImpala")
# rimpala.init()
# rimpala.connect(IP="127.0.0.1",port="21050")
# rimpala.showtables()
# ## End(Not run)

Run the code above in your browser using DataLab