Learn R Programming

RImpala (version 0.1.6)

rimpala.usedatabase: Function to change the current working database

Description

This function changes the current database to the database specified as an argument to the function

Usage

rimpala.usedatabase(db)

Arguments

db
The name of the database.

Value

Changes the database to the specified database and prints "Database changed to " on the console

Examples

Run this code
## Not run: 
# library("RImpala")
# rimpala.init()
# rimpala.connect(127.0.0.1,"21050")
# rimpala.usedatabase(db="sample_db")
# ## End(Not run)

Run the code above in your browser using DataLab